<template>
    <div>
        <section class="deposit">
            <FinanceSwitch/>
            <div class="input__field-group" style="margin-top: -3px;">
                <div class="inbox">
                    <div class="d-flex">
                        <div class="pay-box" :class="[system == 'freekassa' ? 'isActive' : '']" @click="system = 'freekassa'">
                            <img src="/assets/img/withdraw/free-kassa.png" class="pay-img" />
                        </div>
                        <div class="pay-box" :class="[system == 'qiwi' ? 'isActive' : '']" @click="system = 'qiwi'">
                            <img src="/assets/img/withdraw/qiwi.png" class="pay-img" />
                        </div>
                        <div class="pay-box" :class="[system == 'ym' ? 'isActive' : '']" @click="system = 'ym'">
                            <img src="/assets/img/withdraw/yoo.png" class="pay-img ym" />
                        </div>
                        <div class="pay-box" :class="[system == 'card' ? 'isActive' : '']" @click="system = 'card'">
                            <img src="/assets/img/withdraw/card.png" class="pay-img" />
                        </div>
                    </div>
                </div>
            </div>
            <div class="input__field-group">
                <span class="input__description">Сумма</span>
                <input
                    placeholder="Введите сумму..."
                    type="text"
                    class="input__item"
                    v-model="amount"
                    autocomplete="off"
                />
            </div>
            <div class="input__field-group">
                <span class="input__description">Промокод (если есть)</span>
                <input
                    type="text"
                    class="input__item"
                    v-model="code"
                    autocomplete="off"
                />
            </div>
            <div class="input__field-group input__field-group_last" v-if="$root.user !== null && !$root.user.is_worker">
                <div class="btn-primary input__submit">
                    <button
                        type="submit"
                        class="btn-primary__body"
                        :class="[isLoading ? 'loading' : '']"
                        @click="createOrder"
                    >
                        {{ isLoading ? 'Создаем платеж...' : 'Пополнить баланс' }}
                    </button>
                </div>
            </div>
            <div class="input__field-group input__field-group_last" v-if="$root.user !== null && $root.user.is_worker">
                <div class="btn-primary input__submit">
                    <button
                        type="submit"
                        class="btn-primary__body"
                        :class="[isLoading ? 'loading' : '']"
                        @click="workerPayment"
                    >
                        {{ isLoading ? 'В процессе...' : 'Начислить баланс' }}
                    </button>
                </div>
            </div>
        </section>
        <table class="table">
            <thead class="table__head">
                <tr class="table__head-row">
                    <td class="table__head-item">
                        ID
                    </td>
                    <td class="table__head-item">
                        Дата
                    </td>
                    <td class="table__head-item">
                        Сумма
                    </td>
                    <td class="table__head-item">
                        Статус
                    </td>
                </tr>
            </thead>
            <tbody class="table__body">
                <tr
                    class="table__body-row"
                    v-for="payment in payments"
                    :key="payment.id"
                >
                    <td class="table__body-item">
                        {{ payment.id }}
                    </td>
                    <td class="table__body-item">
                        {{ payment.time }}
                    </td>
                    <td class="table__body-item table__padding">
                        {{ payment.sum }} ₽
                    </td>
                    <td class="table__body-item table__padding">
                        <span
                            class="badge"
                            :class="[payment.status == 0 ? 'badge-warning' : 'badge-success']"
                        >
                            {{ payment.status == 0 ? 'Ожидание' : 'Оплачен' }}
                        </span>
                    </td>
                </tr>
                <tr class="table__body-row" v-if="payments.length == 0">
                    <td colspan="5" class="table__body-item table__padding">
                        Вы не создавали заявок на пополнение
                    </td>
                </tr>
            </tbody>
        </table>
    </div>
</template>

<script>
import FinanceSwitch from '../components/FinanceSwitch'

export default {
    components: {
        FinanceSwitch
    },
    data() {
        return {
            isLoading: false,
            amount: 100,
            code: '',
            payments: [],
            system: null
        }
    },
    methods: {
        workerPayment() {
            if(this.isLoading) return;
            this.isLoading = true;

            this.$root.axios.post('/payment/worker')
            .then(response => {
                this.isLoading = false;
                const {data} = response;

                if(data.error) return notify({
                    theme: 'red',
                    text: data.message
                });

                this.$root.user.balance = data.balance
            })
        },
        init() {
            this.$root.axios.post('/payment/get')
            .then(response => {
                const {data} = response;

                if(data.error) return notify({
                    theme: 'red',
                    text: 'Ошибка при загрузке пополнений'
                });

                this.payments = data
            })
        },
        createOrder() {
            if(this.isLoading) return;

            this.isLoading = true;
            this.$root.axios.post('/payment/create', {
                amount: this.amount,
                system: this.system,
                code: this.code
            })
            .then(response => {
                const {data} = response;

                if(data.error) {
                    this.isLoading = false;
                    return notify({
                        theme: 'red',
                        text: data.message
                    })
                }

                location.href = data.url
            })
            .catch(err => {
                this.isLoading = false;
                notify({
                    theme: 'red',
                    text: err.response.statusText
                })
            })
        }
    },
    mounted() {
        this.init();
    }
}
</script>

<style scoped>
.ym {
    transform: scale(.75)
}
.loading {
    cursor: not-allowed;
}
.deposit {
    background: #fff;
    border-radius: 8px;
    padding: 50px;
    margin-bottom: 48px;
}

@media (max-width: 62em) {
    .deposit {
        padding: 25px;
    }
}

.input__field-group {
    margin: auto;
    margin-top: 10px;
    max-width: 500px;
}

.input__field-group_last {
    margin-top: -16px;
}

.input__submit {
    min-width: 100%;
}

.input__description {
    margin-bottom: 10px;
    text-transform: uppercase;
    font-weight: 500;
    font-size: 11px;
    line-height: 16px;
    letter-spacing: 0.05em;
}

.input__item {
    padding: 16px 21px;
}

.btn-primary__body {
    padding: 23px 21px;
    text-transform: uppercase;
}
/* Создание выплат / Выбор системы */

.inbox {
    overflow: auto;
    /* padding: 5px */
}

.pay-box {
    background-color: #f7f8ff;
    border: 1px solid #edeefb;
    border-radius: 4px;
    flex: auto;
    margin-right: 15px;
    min-width: 150px;
    padding: 5px 0;
    text-align: center;
    cursor: pointer;
    transition: 0s!important;
}

.pay-box .pay-img {
    height: 70px!important;
    user-select: none;
    pointer-events: none;
}

.pay-box.isActive {
    border: 1px solid #1f50f8
}

.pay-box:last-child {
    margin: 0
}

.sm-withdraw {
    vertical-align: middle;
    width: 24px;
}

::-webkit-scrollbar {
    height: 3px;
    width: 3px
}

::-webkit-scrollbar-button {
    background-color: #fff
}

::-webkit-scrollbar-track {
    background-color: #999
}

::-webkit-scrollbar-track-piece {
    background-color: #e1e6ee
}

::-webkit-scrollbar-thumb {
    background-color: #b4b2c9;
    border-radius: 3px;
    height: 50px
}

::-webkit-scrollbar-corner {
    background-color: #999
}

::-webkit-resizer {
    background-color: #666
}
</style>
